<?php
/**
 * @file
 * Theme file for Projekktor
 */

/**
 * Projekktor template preprocess function.
 */
function template_preprocess_projekktor_container(&$vars) {
  $settings = &$vars['settings'];

  // Each Projekktor instance gets a unique id.
  $projekktor_id = &drupal_static('projekktor_id', 0);
  $vars['id'] = ++$projekktor_id;

  // Prepare elements.
  $items = $vars['items'];
  $vars['items'] = array();
  $playlist_items = array();
  foreach ($items as $delta => $item) {
    if (!empty($item['uri'])) {
      $playlist_item = array();
      $playlist_item[0]['src'] = file_create_url($item['uri']);
      $playlist_item[0]['type'] = $item['filemime'];
    }
    else {
      $playlist_item = array();
      foreach ($item as $key => $value) {
        if (is_int($key)) {
          $playlist_item[$key]['src'] = file_create_url($item[$key]['uri']);
          $playlist_item[$key]['type'] = $item[$key]['filemime'];
        }
      }
    }

    // Sets filename as title if needed.
    if ((!isset($item['title'])) && (isset($item['filename']))) {
      $item['title'] = $item['filename'];
    }
    if (array_key_exists('title', $item)) {
      $playlist_item['config']['title'] = $item['title'];
    }
    if (array_key_exists('poster', $item)) {
      $playlist_item['config']['poster'] = $item['poster'];
    }

    $playlist_items[$delta] = $playlist_item;
  }

  $playlist = $playlist_items;

  // Convert $id to human friendly form for projekktor_add API.
  $player_id = 'projekktor-' . $vars['id'];

  // Convert $settings to human friendly form for projekktor_add API.
  $preset_name = $settings['projekktor_preset'];
  $theme_name = $settings['projekktor_theme'];

  // Attach Projekktor JavaScript.
  projekktor_add($player_id, $preset_name, $theme_name, $playlist);
}

/**
 * Views template preprocess function.
 */
function theme_views_view_projekktor($vars) {
  $items = array();

  $view = $vars['view'];
  $file_field_name = $vars['file_field_name'];
  foreach ($vars['rows'] as $row) {
    $lang = $row->_field_data[$view->base_field]['entity']->language;
    // Omit rows without file field.
    if (!isset($row->_field_data[$view->base_field]['entity']->{$file_field_name})) {
      continue;
    }
    $item = $row->_field_data[$view->base_field]['entity']->{$file_field_name}[$lang][0];
    $items[] = $item;
  }

  return theme('projekktor_container', array(
    'items' => $items,
    'settings' => $vars['options'],
  ));
}
